# Generated by Django 2.1.2 on 2019-11-10 15:22

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djpaypal', '0010_payment_hold'),
    ]

    operations = [
        migrations.AddField(
            model_name='dispute',
            name='buyer_response_due_date',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='dispute',
            name='refund_details',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='dispute',
            name='messages',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, editable=False, null=True),
        ),
    ]
