# Generated by Django 2.0.2 on 2018-02-06 05:20

from django.db import migrations, models


class Migration(migrations.Migration):

	dependencies = [
		("djpaypal", "0001_initial"),
	]

	operations = [
		migrations.AddField(
			model_name="payer",
			name="time_created",
			field=models.DateTimeField(blank=True, null=True, editable=False),
		),
	]
